# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-12-31 11:25:23
@LastEditTime: 2025-07-15 19:08:55
@LastEditors: HuangJianYi
@Description: 
"""
# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-07-11 10:31:39
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class AnalysisGoodsRepurchaseModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(AnalysisGoodsRepurchaseModel, self).__init__(AnalysisGoodsRepurchase, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类


class AnalysisGoodsRepurchase:
    def __init__(self):
        self.id = 0  # 唯一键,根据业务md5int生成
        self.business_id = 0  # 商家标识
        self.platform_id = 0  # 平台标识(1-淘宝 2-抖音 3-京东 4-微信)
        self.store_id = 0  # 店铺标识
        self.goods_id = ''  # 商品ID
        self.total_sales = 0  # 总销量
        self.buyer_count = 0  # 购买人数
        self.repurchase_count = 0  # 复购人数
        self.repurchase_rate = 0  # 复购率
        self.avg_purchase_times = 0  # 人均购买次数
        self.avg_repurchase_cycle = 0  # 平均复购周期(天)
        self.today_expired_count = 0  # 今日到期未购买人数
        self.recent_7days_expired_count = 0  # 近7日到期未购买人数
        self.stat_date = 0  # 统计时间(20241231)
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'business_id', 'platform_id', 'store_id', 'goods_id', 'total_sales', 'buyer_count', 'repurchase_count', 'repurchase_rate', 'avg_purchase_times', 'avg_repurchase_cycle', 'today_expired_count', 'recent_7days_expired_count', 'stat_date', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "analysis_goods_repurchase_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2025-04-17 11:01:05
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class TaobaoSourceHistoryMemberModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TaobaoSourceHistoryMemberModel, self).__init__(TaobaoSourceHistoryMember, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class TaobaoSourceHistoryMember:
    def __init__(self):
        super(TaobaoSourceHistoryMember, self).__init__()
        self.ouid = "" # 外部用户ID
        self.store_id = "" # 店铺id
        self.grade = 0 # 等级编码
        self.grade_name = ""  # 等级名称
        self.snapshot_info = ""  # 版本拓展信息
        self.gmt_modified = '1900-01-01 00:00:00.000' # 记录最后修改时间
        self.points = "" # 消费者积分余额
        self.mix_mobile = "" # 加密手机号
        self.mobile = "" # 手机号
        self.first_entry_time = "1900-01-01 00:00:00" # 首次入会时间
        self.last_entry_time = "1900-01-01 00:00:00" # 首次入会时间
        self.modify_time = "1900-01-01 00:00:00.000" # 修改时间
        self.create_time = "1900-01-01 00:00:00.000" # 创建时间

    @classmethod
    def get_field_list(self):
        return ["ouid", "store_id", "grade", "grade_name", "snapshot_info", "gmt_modified", "points", "mix_mobile", "mobile", "first_entry_time", "last_entry_time", "modify_time", "create_time"]

    @classmethod
    def get_primary_key(self):
        return "ouid"

    def __str__(self):
        return "taobao_source_history_member_tb"




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class PrefixInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PrefixInfoModel, self).__init__(PrefixInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class PrefixInfo:

    def __init__(self):
        super(PrefixInfo, self).__init__()
        self.id = 0  # 
        self.guid = None  # 
        self.prefix = ""  # 
        self.status = 0  # 
        self.updated_by_id = 0  # 
        self.created_by_id = 0  # 
        self.updated_at = "1900-01-01 00:00:00"  # 
        self.created_at = "1900-01-01 00:00:00"  # 
        self.create_date = "1900-01-01 00:00:00"  # 

    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'prefix', 'status', 'updated_by_id', 'created_by_id', 'updated_at', 'created_at', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "prefix_info_tb"
    


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-06 09:39:45
@LastEditTime: 2025-07-11 10:34:43
@LastEditors: HuangJianYi
@Description: 
"""

# 此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class CdpStoreInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(CdpStoreInfoModel, self).__init__(CdpStoreInfo, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class CdpStoreInfo:

    def __init__(self):
        super(CdpStoreInfo, self).__init__()
        self.id = 0  # id
        self.guid = None  # guid
        self.store_name = ""  # 店铺名称
        self.store_icon = ""  # 店铺图标
        self.plat_store_id = ""  # 平台店铺标识
        self.store_status = 0  # 店铺状态
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间
        self.modify_date = '1970-01-01 00:00:00.000'  # 修改时间
        self.plat_telephone_key = ""  # 平台手机号密钥
        self.prefix_status = 0  # 号段生成状态
        self.prefix_path = ""  # 号段存储路径
        self.business_id = 0  # 商家标识
        self.seller_nick = ""  # 店铺主账号
        self.seller_id = "" # 店铺主账号id
        self.platform_id = 0  # 平台类型
        self.overdue_date = '1970-01-01 00:00:00.000'  # 过期时间
        self.access_token = ""  # access_token
        self.extend_info = {} # 扩展信息json
        self.description = ""  # 描述
        self.cdp_rawdata_sync_status = 0  # cdp_原始数据同步状态(0-未开始 1-同步历史数据 2-同步增量数据)
        self.history_data_clean_status = 0  # 历史数据清洗状态(0-未开始 1-进行中 2-已完成)
        self.history_member_init_status = 0 # 历史会员初始化状态(0-未开始 1-进行中 2-已完成)
        self.is_stark_work = 0  # 是否开启作业服务(1-是 0-否)


    @classmethod
    def get_field_list(self):
        return [
            'id', 'guid', 'store_name', 'store_icon', 'plat_store_id', 'store_status', 'create_date', 'modify_date', 'plat_telephone_key', 'prefix_status', 'prefix_path', 'business_id', 'seller_nick', 'seller_id', 'platform_id', 'overdue_date', 'access_token', 'extend_info',
            'description', 'cdp_rawdata_sync_status', 'history_data_clean_status', 'history_member_init_status', 'is_stark_work'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cdp_store_info_tb"



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class TtRdsTradeModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(TtRdsTradeModel, self).__init__(TtRdsTrade, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class TtRdsTrade:
    def __init__(self):
        super(TtRdsTrade, self).__init__()
        self.id = 0  # 主键id
        self.order_id = ""  # 订单id
        self.order_status = 0  # 订单状态
        self.order_type = 0  # 订单类型
        self.shop_id = 0  # 店铺id
        self.doudian_open_id = ""  # 加密用户id串
        self.create_time = 0  # 订单创建时间
        self.update_time = 0  # 订单更新时间
        self.ddp_created = ""  # 数据推送创建时间
        self.ddp_modified = ""  # 数据推送更新时间
        self.ddp_response = {}  # API返回的整个JSON字符串
        self.version = 0  # 版本号
        self.digest = ""  # 业务摘要
        self.version_update_time = 0  # 版本更新时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'order_id', 'order_status', 'order_type', 'shop_id',
            'doudian_open_id', 'create_time', 'update_time', 'ddp_created',
            'ddp_modified', 'ddp_response', 'version', 'digest', 'version_update_time'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "tt_rds_trade_tb"



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class StorePrefixLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(StorePrefixLogModel, self).__init__(StorePrefixLog, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StorePrefixLog:

    def __init__(self):
        super(StorePrefixLog, self).__init__()
        self.id = 0  # 主键id
        self.store = ""  # 店铺guid
        self.prefix = ""  # 号段
        self.status = 0  # 状态(0-未生成 1已生成)
        self.created_at = "1900-01-01 00:00:00"  #
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'store', 'prefix', 'status', 'created_at', 'create_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "store_prefix_log_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-10-15 18:30:21
@LastEditTime: 2024-11-14 15:22:28
@LastEditors: HuangJianYi
@Description: 
"""
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class MemberLevelLogModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(MemberLevelLogModel, self).__init__(MemberLevelLog, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    # 方法扩展请继承此类

class MemberLevelLog:
    def __init__(self):
        super(MemberLevelLog, self).__init__()
        self.id = 0
        self.business_id = 0  # 商家标识
        self.scheme_id = 0 # 体系标识
        self.change_no = ""  # 变更流水号
        self.one_id = ""  # one_id
        self.log_title = ""  # 标题
        self.source_type = 0  # 来源类型(1-系统 2-人工)
        self.source_object_id = ""  # 来源对象标识
        self.source_object_name = ""  # 来源对象名称
        self.operate_type = 0  # 变更类型 （0-初始化 1-升级 2-降级 3-保级）
        self.old_level_id = 0  # 变更前等级标识
        self.new_level_id = 0  # 变更后等级标识
        self.valid_type = 0  # 有效期类型(1-永久有效 2-指定时间)
        self.level_valid_date = '1970-01-01 00:00:00.000'  # 会员等级有效期
        self.remark = ""  # 备注
        self.operate_user_id = ""  # 操作用户标识
        self.operate_user_name = ""  # 操作用户名称
        self.create_date = '1970-01-01 00:00:00.000'  # 创建时间

    @classmethod
    def get_field_list(self):
        return [
            'id', 'business_id', 'scheme_id', 'change_no', 'one_id', 'log_title', 'source_type', 'source_object_id', 'source_object_name', 'operate_type', 'old_level_id', 'new_level_id', 'valid_type', 'level_valid_date', 'remark', 'operate_user_id', 'operate_user_name',
            'create_date'
        ]

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "member_level_log_tb"
